==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/pl/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "teraz",
	"field-weekday": "dzień tygodnia",
	"field-wed-relative+0": "w tę środę",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-wed-relative+1": "w przyszłą środę",
	"field-tue-relative+-1": "w zeszły wtorek",
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-wed-relative+-1": "w zeszłą środę",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, d MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d.MM.y G",
	"field-thu-relative+-1": "w zeszły czwartek",
	"dateFormatItem-Md": "d.MM",
	"field-era": "era",
	"field-year": "rok",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-MMdd": "d.MM",
	"field-hour": "godzina",
	"field-sat-relative+0": "w tę sobotę",
	"field-sat-relative+1": "w przyszłą sobotę",
	"field-day-relative+0": "dzisiaj",
	"field-day-relative+1": "jutro",
	"field-thu-relative+0": "w ten czwartek",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "pojutrze",
	"field-thu-relative+1": "w przyszły czwartek",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-sun-relative+0": "w tę niedzielę",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"field-minute": "minuta",
	"field-dayperiod": "rano / po południu / wieczorem",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "wczoraj",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1}, {0}",
	"field-day-relative+-2": "przedwczoraj",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d.MM",
	"dateTimeFormat-full": "{1}, {0}",
	"field-fri-relative+0": "w ten piątek",
	"field-fri-relative+1": "w przyszły piątek",
	"field-day": "dzień",
	"field-zone": "strefa czasowa",
	"dateFormatItem-yyyyMM": "MM.y G",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "w zeszłym roku",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-yyyyMd": "d.MM.y G",
	"field-month": "miesiąc",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "w ten wtorek",
	"field-tue-relative+1": "w przyszły wtorek",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"dateFormat-short": "dd.MM.y G",
	"field-second": "sekunda",
	"field-sat-relative+-1": "w zeszłą sobotę",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"field-month-relative+0": "w tym miesiącu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"dateFormatItem-Ed": "E, d",
	"field-week": "tydzień",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "w tym roku",
	"field-week-relative+-1": "Zeszły tydzień",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-year-relative+1": "w przyszłym roku",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "w tym tygodniu",
	"field-week-relative+1": "w przyszłym tygodniu"
}
//end v1.x content
);

==> dojo_1.14.2+dfsg1.orig.tar.gz: dojo-release-1.14.2-src/dojo/cldr/nls/pl/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "teraz",
	"field-weekday": "dzień tygodnia",
	"field-wed-relative+0": "w tę środę",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-wed-relative+1": "w przyszłą środę",
	"field-tue-relative+-1": "w zeszły wtorek",
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-wed-relative+-1": "w zeszłą środę",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1}, {0}",
	"dateFormat-full": "EEEE, d MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d.MM.y G",
	"field-thu-relative+-1": "w zeszły czwartek",
	"dateFormatItem-Md": "d.MM",
	"field-era": "era",
	"field-year": "rok",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-MMdd": "d.MM",
	"field-hour": "godzina",
	"field-sat-relative+0": "w tę sobotę",
	"field-sat-relative+1": "w przyszłą sobotę",
	"field-day-relative+0": "dzisiaj",
	"field-day-relative+1": "jutro",
	"field-thu-relative+0": "w ten czwartek",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "pojutrze",
	"field-thu-relative+1": "w przyszły czwartek",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-sun-relative+0": "w tę niedzielę",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"field-minute": "minuta",
	"field-dayperiod": "rano / po południu / wieczorem",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "wczoraj",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1}, {0}",
	"field-day-relative+-2": "przedwczoraj",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d.MM",
	"dateTimeFormat-full": "{1}, {0}",
	"field-fri-relative+0": "w ten piątek",
	"field-fri-relative+1": "w przyszły piątek",
	"field-day": "dzień",
	"field-zone": "strefa czasowa",
	"dateFormatItem-yyyyMM": "MM.y G",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "w zeszłym roku",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-yyyyMd": "d.MM.y G",
	"field-month": "miesiąc",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "w ten wtorek",
	"field-tue-relative+1": "w przyszły wtorek",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"dateFormat-short": "dd.MM.y G",
	"field-second": "sekunda",
	"field-sat-relative+-1": "w zeszłą sobotę",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"field-month-relative+0": "w tym miesiącu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"dateFormatItem-Ed": "E, d",
	"field-week": "tydzień",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "w tym roku",
	"field-week-relative+-1": "w zeszłym tygodniu",
	"dateFormatItem-yyyyM": "MM.y G",
	"field-year-relative+1": "w przyszłym roku",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "w tym tygodniu",
	"field-week-relative+1": "w przyszłym tygodniu"
}
//end v1.x content
);
